@@ -37,7 +37,11 @@ class AppStoreValidator:
         :param sandbox: sandbox mode ?
         :param auto_retry_wrong_env_request: auto retry on wrong env ?
         """
-        warnings.warn("bundle_id will be removed in version 3, since it's not used here.", PendingDeprecationWarning)
+        if bundle_id:
+            warnings.warn(
+                "bundle_id will be removed in version 3, since it's not used here.",
+                PendingDeprecationWarning,
+            )
 
         self.bundle_id = bundle_id
         self.sandbox = sandbox
@@ -72,7 +76,12 @@ class AppStoreValidator:
         except (ValueError, RequestException):
             raise InAppPyValidationError("HTTP error")
 
-    def validate(self, receipt: str, shared_secret: str = None, exclude_old_transactions: bool = False) -> dict:
+    def validate(
+        self,
+        receipt: str,
+        shared_secret: str = None,
+        exclude_old_transactions: bool = False,
+    ) -> dict:
         """Validates receipt against apple services.
 
         :param receipt: receipt
